@@ -70,7 +70,7 @@ data StatInfo = StatInfo
 type StatState = StateT StatInfo Annex
 
 def :: [Command]
-def = [command "status" paramPaths seek
+def = [noCommit $ command "status" paramPaths seek
 	SectionQuery "shows status information about the annex"]
 
 seek :: [CommandSeek]
@@ -311,15 +311,16 @@ getLocalStatInfo dir = do
 	initial = (emptyKeyData, emptyKeyData, emptyNumCopiesStats)
 	update matcher fast key file vs@(presentdata, referenceddata, numcopiesstats) =
 		ifM (matcher $ FileInfo file file)
-			( (,,)
-				<$> ifM (inAnnex key)
+			( do
+				!presentdata' <- ifM (inAnnex key)
 					( return $ addKey key presentdata
 					, return presentdata
 					)
-				<*> pure (addKey key referenceddata)
-				<*> if fast
+				let !referenceddata' = addKey key referenceddata
+				!numcopiesstats' <- if fast
 					then return numcopiesstats
 					else updateNumCopiesStats key file numcopiesstats
+				return $! (presentdata', referenceddata', numcopiesstats')
 			, return vs
 			)
 
@@ -345,11 +346,11 @@ addKey key (KeyData count size unknownsize backends) =
 	ks = keySize key
 
 updateNumCopiesStats :: Key -> FilePath -> NumCopiesStats -> Annex NumCopiesStats
-updateNumCopiesStats key file stats = do
-	variance <- Variance <$> numCopiesCheck file key (-)
-	return $ stats { numCopiesVarianceMap = update (numCopiesVarianceMap stats) variance }
-  where
-  	update m variance = M.insertWith' (+) variance 1 m
+updateNumCopiesStats key file (NumCopiesStats m) = do
+	!variance <- Variance <$> numCopiesCheck file key (-)
+	let !m' = M.insertWith' (+) variance 1 m
+	let !ret = NumCopiesStats m'
+	return ret
 
 showSizeKeys :: KeyData -> String
 showSizeKeys d = total ++ missingnote
@@ -362,7 +363,7 @@ showSizeKeys d = total ++ missingnote
 			" keys of unknown size"
 
 staleSize :: String -> (Git.Repo -> FilePath) -> Stat
-staleSize label dirspec = go =<< lift (Command.Unused.staleKeys dirspec)
+staleSize label dirspec = go =<< lift (dirKeys dirspec)
   where
 	go [] = nostat
 	go keys = onsize =<< sum <$> keysizes keys
@@ -370,10 +371,11 @@ staleSize label dirspec = go =<< lift (Command.Unused.staleKeys dirspec)
 	onsize size = stat label $
 		json (++ aside "clean up with git-annex unused") $
 			return $ roughSize storageUnits False size
-	keysizes keys = map (fromIntegral . fileSize) <$> stats keys
-	stats keys = do
+	keysizes keys = do
 		dir <- lift $ fromRepo dirspec
-		liftIO $ forM keys $ \k -> getFileStatus (dir </> keyFile k)
+		liftIO $ forM keys $ \k -> catchDefaultIO 0 $
+			fromIntegral . fileSize 
+				<$> getFileStatus (dir </> keyFile k)
 
 aside :: String -> String
 aside s = " (" ++ s ++ ")"
