@@ -15,54 +15,49 @@
 
 module Logs.Location (
 	LogStatus(..),
+	logStatus,
 	logChange,
 	loggedLocations,
 	loggedKeys,
 	loggedKeysFor,
-	logFile,
-	logFileKey
 ) where
 
 import Common.Annex
 import qualified Annex.Branch
+import Logs
 import Logs.Presence
+import Annex.UUID
+
+{- Log a change in the presence of a key's value in current repository. -}
+logStatus :: Key -> LogStatus -> Annex ()
+logStatus key s = do
+	u <- getUUID
+	logChange key u s
 
 {- Log a change in the presence of a key's value in a repository. -}
 logChange :: Key -> UUID -> LogStatus -> Annex ()
-logChange key (UUID u) s = addLog (logFile key) =<< logNow s u
+logChange key (UUID u) s = addLog (locationLogFile key) =<< logNow s u
 logChange _ NoUUID _ = noop
 
 {- Returns a list of repository UUIDs that, according to the log, have
  - the value of a key.
  -}
 loggedLocations :: Key -> Annex [UUID]
-loggedLocations key = map toUUID <$> (currentLog . logFile) key
+loggedLocations key = map toUUID <$> (currentLog . locationLogFile) key
 
 {- Finds all keys that have location log information.
  - (There may be duplicate keys in the list.) -}
 loggedKeys :: Annex [Key]
-loggedKeys = mapMaybe (logFileKey . takeFileName) <$> Annex.Branch.files
+loggedKeys = mapMaybe locationLogFileKey <$> Annex.Branch.files
 
 {- Finds all keys that have location log information indicating
  - they are present for the specified repository. -}
 loggedKeysFor :: UUID -> Annex [Key]
 loggedKeysFor u = filterM isthere =<< loggedKeys
-	where
-		{- This should run strictly to avoid the filterM
-		 - building many thunks containing keyLocations data. -}
-		isthere k = do
-			us <- loggedLocations k
-			let !there = u `elem` us
-			return there
-
-{- The filename of the log file for a given key. -}
-logFile :: Key -> String
-logFile key = hashDirLower key ++ keyFile key ++ ".log"
-
-{- Converts a log filename into a key. -}
-logFileKey :: FilePath -> Maybe Key
-logFileKey file
-	| ext == ".log" = fileKey base
-	| otherwise = Nothing
-	where
-		(base, ext) = splitAt (length file - 4) file
+  where
+	{- This should run strictly to avoid the filterM
+	 - building many thunks containing keyLocations data. -}
+	isthere k = do
+		us <- loggedLocations k
+		let !there = u `elem` us
+		return there
