@@ -24,6 +24,7 @@ import Data.Time.Clock.POSIX
 import Common.Annex
 import qualified Annex.Branch
 import qualified Annex
+import Logs
 import Logs.UUIDBased
 import Limit
 import qualified Utility.Matcher
@@ -35,10 +36,6 @@ import Logs.Group
 import Logs.Remote
 import Types.StandardGroups
 
-{- Filename of preferred-content.log. -}
-preferredContentLog :: FilePath
-preferredContentLog = "preferred-content.log"
-
 {- Changes the preferred content configuration of a remote. -}
 preferredContentSet :: UUID -> String -> Annex ()
 preferredContentSet uuid@(UUID _) val = do
